@@ -27,10 +27,19 @@ class Argument:
         default: Optional[TypeConstant] = None,
         prefix: str = "",
     ):
-        self.name = name
-        self.type_annotation = type_annotation
-        self.default = default
-        self.prefix = prefix
+        self.name: str = name
+        self.type_annotation: Optional[FakeAnnotation] = type_annotation
+        self.default: Optional[TypeConstant] = default
+        self.prefix: str = prefix
+
+    def render(self) -> str:
+        """
+        Render argument to a string.
+        """
+        if not self.type_annotation:
+            return f"{self.name} = {self.default}"
+
+        return f"{self.name}: {self.type_annotation.render()} = {self.default}"
 
     @classmethod
     def kwflag(cls: Type[_R]) -> _R:
