@@ -3,6 +3,7 @@ Multiple string utils collection.
 """
 import builtins
 import keyword
+import textwrap
 import typing
 from typing import List
 
@@ -13,6 +14,7 @@ RESERVED_NAMES = set(
         *keyword.kwlist,
     )
 )
+MAX_DOCSTRING_LENGTH: int = 300
 
 
 def get_class_prefix(func_name: str) -> str:
@@ -100,3 +102,40 @@ def is_reserved(word: str) -> bool:
     Check whether varialbe name conflicts with Python reserved names.
     """
     return word in RESERVED_NAMES
+
+
+def get_short_docstring(doc: str) -> str:
+    """
+    Create a short docstring from boto3 documentation.
+
+    Trims docstring to 300 chars.
+    Removes double and trible backticks.
+    Ensures that backticks are closed.
+    Wraps docstring to 80 chars.
+    """
+    doc = str(doc)
+    if len(doc) > MAX_DOCSTRING_LENGTH:
+        doc = f"{doc[:MAX_DOCSTRING_LENGTH - 3]}..."
+    result = []
+    if not doc:
+        return ""
+    for line in doc.splitlines():
+        line = line.strip().rstrip("::")
+        if line.startswith(":"):
+            break
+        if not line:
+            continue
+        if ". " in line:
+            result.append(line.split(". ")[0])
+            break
+        result.append(line)
+        if line.endswith("."):
+            break
+
+    result_str = " ".join(result).replace("```", "`").replace("``", "`").strip()
+    if result_str.count("`") % 2:
+        result_str = f"{result_str}`"
+    if result_str and not result_str.endswith("."):
+        result_str = f"{result_str}."
+
+    return "\n".join(textwrap.wrap(result_str, width=80))
